/*
 * Master Telescope Driver A
 * @date March 12 ,2022
 */
#include "simpletools.h"    // Include simple tools
#include "propeller.h"
#include "fdserial.h"

void readModePin(void);
void readDirectionPins(void);
void sendSerialData(void);
void setup(void);

#define westPin            0
#define northPin           1
#define eastPin            2
#define southPin           3
#define modePin            4
#define lowLedPin          7
#define med1LedPin         8
#define med2LedPin         9
#define highLedPin         10

#define rx                 5
#define tx                 6

char currentModeSwitchState  = 0;
char lastModeSwitchState     = 0;
char ModeSwitch              = 0;
char direction               = 0;
char mode                    = 0;
char West, North, East, South;
fdserial *conn;

int main()                                    // Main function
{
  low(lowLedPin);
  low(med1LedPin);
  low(med2LedPin);
  low(highLedPin);
  
  int i;
  
  setup();
  
  while(1)
  {
    readModePin();
    readDirectionPins();
    if (direction != 0)
    {
      writeDec(conn,mode);
      writeChar(conn, direction);
      writeChar(conn, '\n');
      direction = 0;
    }
    pause(50);      
  }  
}

void readModePin()
{
  currentModeSwitchState = input(modePin);
  if(currentModeSwitchState != lastModeSwitchState)
  {
    lastModeSwitchState = currentModeSwitchState;
    if(currentModeSwitchState == 0)
    {
      mode++;
      if(mode > 4)
      {
        mode = 1;
      }
    }
    else
    {}
  }
    switch(mode)
    {
      case 1:
        high(lowLedPin);
        low(med1LedPin);
        low(med2LedPin);
        low(highLedPin);
        break;
      
      case 2:
        low(lowLedPin);
        high(med1LedPin);
        low(med2LedPin);
        low(highLedPin);
        break;
        
      case 3:
        low(lowLedPin);
        low(med1LedPin);
        high(med2LedPin);
        low(highLedPin);
        break;
        
      case 4:
        low(lowLedPin);
        low(med1LedPin);
        low(med2LedPin);
        high(highLedPin);
        break;
        
      default:
      {}
    }
  }          
                          
        
  
void setup()
{
  conn  = fdserial_open(rx, tx, 0, 115200);
  West  = input(westPin);
  North = input(northPin);
  East  = input(eastPin) ;
  South = input(southPin);
}
/**
 * get move direction
 * 0 - none
 * 1 - west
 * 2 - north
 * 3 - east
 * 4 - south
 */
void readDirectionPins()
{
  int i;
  
  i = input(westPin);
  if (i != West)
  {
    if(i == 1)
      direction = 'W';
    West = i;
  }    
    
  i = input(northPin);
  if (i != North)
  {
    if (i == 1)
      direction = 'N';
    North = i;
  }
  i = input(eastPin);
  if(i != East)
  {
    if (i == 1)
      direction = 'E';
    East = i;
  }
  i = input(southPin);
  if(i != South)
  {
    if(i == 1)
      direction = 's';  
    South = i;
  }
}            
     
  
